Documentation
¶
Index ¶
- Constants
- func EnsureProjectSkill(projectRoot string) (path string, created bool, err error)
- func IsToolRegistered(registry *tools.Registry) bool
- func RegisterTool(registry *tools.Registry)
- func RemoveTool(registry *tools.Registry)
- type Tool
- func (t *Tool) Description() string
- func (t *Tool) Execute(ctx context.Context, params map[string]any) (result tools.ToolResult, err error)
- func (t *Tool) ExecutionTimeout(params map[string]any) (time.Duration, bool)
- func (t *Tool) Name() string
- func (t *Tool) Parameters() json.RawMessage
- func (t *Tool) PromptGuidelines() []string
- func (t *Tool) PromptSnippet() string
Constants ¶
const ( ToolName = "browser" SkillName = "vibe-browser" )
Variables ¶
This section is empty.
Functions ¶
func EnsureProjectSkill ¶
EnsureProjectSkill creates the project-local browser skill if it does not already exist. Existing SKILL.md or skill.md files are never overwritten so user customizations keep priority.
func IsToolRegistered ¶
func RegisterTool ¶
func RemoveTool ¶
Types ¶
type Tool ¶
type Tool struct {
// contains filtered or unexported fields
}
func (*Tool) Description ¶
func (*Tool) ExecutionTimeout ¶
func (*Tool) Parameters ¶
func (t *Tool) Parameters() json.RawMessage
func (*Tool) PromptGuidelines ¶
func (*Tool) PromptSnippet ¶
Click to show internal directories.
Click to hide internal directories.