browser

package
v1.1.60 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 6, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

const (
	ToolName  = "browser"
	SkillName = "vibe-browser"
)

Variables

This section is empty.

Functions

func EnsureProjectSkill

func EnsureProjectSkill(projectRoot string) (path string, created bool, err error)

EnsureProjectSkill creates the project-local browser skill if it does not already exist. Existing SKILL.md or skill.md files are never overwritten so user customizations keep priority.

func IsToolRegistered

func IsToolRegistered(registry *tools.Registry) bool

func RegisterTool

func RegisterTool(registry *tools.Registry)

func RemoveTool

func RemoveTool(registry *tools.Registry)

Types

type Tool

type Tool struct {
	// contains filtered or unexported fields
}

func NewTool

func NewTool(registry *tools.Registry) *Tool

func (*Tool) Description

func (t *Tool) Description() string

func (*Tool) Execute

func (t *Tool) Execute(ctx context.Context, params map[string]any) (result tools.ToolResult, err error)

func (*Tool) ExecutionTimeout

func (t *Tool) ExecutionTimeout(params map[string]any) (time.Duration, bool)

func (*Tool) Name

func (t *Tool) Name() string

func (*Tool) Parameters

func (t *Tool) Parameters() json.RawMessage

func (*Tool) PromptGuidelines

func (t *Tool) PromptGuidelines() []string

func (*Tool) PromptSnippet

func (t *Tool) PromptSnippet() string

Jump to