Documentation
¶
Overview ¶
Package commondb owns the process-wide SQLite connection lifecycle.
Index ¶
- func CanonicalPath(path string) (string, error)
- func CloseAll() error
- func DSNForOS(path string, windows bool) string
- func Open(path string, migrate Migrator) (*sql.DB, error)
- func OpenStandalone(path string, migrate Migrator) (*sql.DB, error)
- func Query(path string, migrate Migrator, fn func(*sql.DB) error) error
- func Write(ctx context.Context, path string, migrate Migrator, fn func(*sql.Tx) error) error
- type Migrator
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CanonicalPath ¶
func DSNForOS ¶
DSNForOS returns the configured SQLite file URI. It is exported for platform-specific integration tests.
func OpenStandalone ¶
OpenStandalone opens an uncached connection for tools that explicitly own its lifecycle, such as offline integrity checks.
Types ¶
Click to show internal directories.
Click to hide internal directories.