Documentation
¶
Index ¶
- func ConfigPath() string
- func DecodeConfigBytesInto(cfg *Config, data []byte) error
- func InitConfig(force bool) (string, error)
- func InitConfigForProject(project bool, force bool) (string, error)
- func ProjectConfigPath() string
- func Run(opts RunOptions, version string) error
- func SaveConfig(path string, cfg *Config) error
- type ChannelConfig
- type Config
- type FeatureConfig
- type RunOptions
- type WebUIConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigPath ¶
func ConfigPath() string
func DecodeConfigBytesInto ¶
func InitConfig ¶
func InitConfigForProject ¶ added in v1.1.61
func ProjectConfigPath ¶
func ProjectConfigPath() string
func Run ¶
func Run(opts RunOptions, version string) error
func SaveConfig ¶
Types ¶
type ChannelConfig ¶
type ChannelConfig struct {
Wechat channels.WechatConfig `json:"wechat"`
Feishu channels.FeishuConfig `json:"feishu"`
}
type Config ¶
type Config struct {
API openaiapi.Config `json:"api"`
Features FeatureConfig `json:"features"`
Channels ChannelConfig `json:"channels"`
WebUI WebUIConfig `json:"webUI"`
LobsterMode bool `json:"lobsterMode,omitempty"`
Cron channels.CronConfig `json:"cron"`
Memory channels.MemoryConfig `json:"memory"`
Security channels.SecurityConfig `json:"security"`
Hooks channels.HooksConfig `json:"hooks"`
Agent channels.AgentConfig `json:"agent"`
}
func DecodeConfigBytes ¶
func DefaultConfig ¶
func DefaultConfig() *Config
func LoadConfig ¶
func LoadConfigFrom ¶
func (*Config) MarshalJSON ¶
type FeatureConfig ¶
type FeatureConfig struct {
WebUI bool `json:"webUI,omitempty"`
OpenAIAPI bool `json:"openaiAPI,omitempty"`
Wechat bool `json:"wechat,omitempty"`
Feishu bool `json:"feishu,omitempty"`
WebSocket bool `json:"websocket,omitempty"`
MultiAgent bool `json:"multiAgent,omitempty"`
Cron bool `json:"cron,omitempty"`
Memory bool `json:"memory,omitempty"`
}
type RunOptions ¶
type WebUIConfig ¶
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package hooks implements shell hook scripts for serve channels.
|
Package hooks implements shell hook scripts for serve channels. |
|
Package webhook implements inbound webhook routing for serve channels.
|
Package webhook implements inbound webhook routing for serve channels. |
|
Package ws implements the serve WebSocket channel runtime.
|
Package ws implements the serve WebSocket channel runtime. |
Click to show internal directories.
Click to hide internal directories.