Documentation
¶
Index ¶
- type App
- func NewApp(p provider.Provider, model *provider.Model, settings *config.Settings, ...) *App
- func NewAppWithWorkflows(p provider.Provider, model *provider.Model, settings *config.Settings, ...) *App
- func NewAppWithWorkflowsAndAllow(p provider.Provider, model *provider.Model, settings *config.Settings, ...) *App
- func (a *App) Init() tea.Cmd
- func (a *App) LoadHistoryMessages()
- func (a *App) ReloadRequested() bool
- func (a *App) SetAutoOpenAuthDialog(v bool)
- func (a *App) SetBrowserEnabled(enabled bool, skillInBase bool)
- func (a *App) SetInitialMessage(msg string)
- func (a *App) SetProgram(p *tea.Program)
- func (a *App) ShowUpdateNotice(notice string)
- func (a *App) Update(msg tea.Msg) (tea.Model, tea.Cmd)
- func (a *App) View() string
- type ClipboardImageSaver
- type FileOpener
- type InputEvent
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
// contains filtered or unexported fields
}
App is the main TUI application.
func NewApp ¶
func NewApp(p provider.Provider, model *provider.Model, settings *config.Settings, sess *session.Manager, registry *tools.Registry, sandboxInfo string, extraContext string, skillsMgr *skills.Manager, initialMode string, multiAgent bool, delegateMode bool, agentMgr *agent.AgentManager, cronStore cron.CronStore, scheduler *cron.Scheduler) *App
NewApp creates a new TUI application.
func NewAppWithWorkflows ¶
func NewAppWithWorkflows(p provider.Provider, model *provider.Model, settings *config.Settings, sess *session.Manager, registry *tools.Registry, sandboxInfo string, extraContext string, skillsMgr *skills.Manager, initialMode string, multiAgent bool, delegateMode bool, workflows bool, agentMgr *agent.AgentManager, cronStore cron.CronStore, scheduler *cron.Scheduler) *App
func NewAppWithWorkflowsAndAllow ¶
func NewAppWithWorkflowsAndAllow(p provider.Provider, model *provider.Model, settings *config.Settings, sess *session.Manager, registry *tools.Registry, sandboxInfo string, extraContext string, skillsMgr *skills.Manager, initialMode string, multiAgent bool, delegateMode bool, workflows bool, agentMgr *agent.AgentManager, cronStore cron.CronStore, scheduler *cron.Scheduler, providerKey string, allow *config.AllowConfig) *App
NewAppWithWorkflowsAndAllow creates a new TUI application. providerKey is the user-configured settings.json provider key (e.g. "xiaomi", "doubao"); when empty the resolved vendor name from p.Name() is used as a fallback.
func (*App) LoadHistoryMessages ¶
func (a *App) LoadHistoryMessages()
LoadHistoryMessages loads messages from session history into TUI display.
func (*App) ReloadRequested ¶
ReloadRequested reports whether the user asked to reload via /reload.
func (*App) SetAutoOpenAuthDialog ¶
SetAutoOpenAuthDialog tells the TUI to open the /auth dialog automatically on startup. This is used when settings.json was just created.
func (*App) SetBrowserEnabled ¶
SetBrowserEnabled records browser-tool startup state. skillInBase is true when the browser skill context has already been included in baseExtraContext.
func (*App) SetInitialMessage ¶
SetInitialMessage sets an initial message to display when the TUI starts.
func (*App) SetProgram ¶
SetProgram stores the Bubble Tea program used for deferred UI updates.
func (*App) ShowUpdateNotice ¶
ShowUpdateNotice displays an update notification from a background check.
type ClipboardImageSaver ¶
type FileOpener ¶
type InputEvent ¶
type InputEvent struct {
// contains filtered or unexported fields
}
InputEvent represents a queued input event
Source Files
¶
- activity.go
- agent_events.go
- agent_tabbar.go
- app.go
- app_paste.go
- app_render.go
- approval.go
- auth_dialog.go
- auth_model.go
- auth_provider.go
- auth_render.go
- auth_settings.go
- auth_settings_top.go
- auth_state.go
- btw.go
- clipboard_image.go
- command_render.go
- command_suggest.go
- commands.go
- commands_session.go
- commands_stats.go
- commands_statusline.go
- default_model_dialog.go
- events.go
- formatters.go
- header.go
- input.go
- loading.go
- model_dialog.go
- render.go
- state.go
- statusline_app.go
- todo_list.go
- tool_modal.go