Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsWithinPath ¶ added in v1.1.65
IsWithinPath reports whether candidate is equal to or below parent after resolving all existing symlinks in both paths.
func ResolvePathWithExistingSymlinks ¶ added in v1.1.65
ResolvePathWithExistingSymlinks returns an absolute path after resolving all existing components. Missing descendants are retained beneath the resolved nearest existing ancestor.
func TruncateString ¶
TruncateString returns a valid UTF-8 prefix of s whose byte length is at most maxBytes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.